ScriptKind

Enum ScriptKind 

pub enum ScriptKind {
    PubKeyHash {
        hash: [u8; 20],
    },
    ScriptHash {
        hash: [u8; 20],
    },
    MultiSig {
        required: u8,
        pubkeys: Vec<BoundedVec<u8, { PubKey::COMPRESSED_SIZE }, { PubKey::SIZE }>>,
    },
    NullData {
        data: Vec<PushValue>,
    },
    PubKey {
        data: BoundedVec<u8, { PubKey::COMPRESSED_SIZE }, { PubKey::SIZE }>,
    },
}
Known kinds of standard scripts.

Variants



PubKeyHash

A P2PKH script.

Fields

hash: [u8; 20]

The Hash160 of the public key.



ScriptHash

A P2SH script, used in transaction outputs to efficiently commit to other scripts.

Fields

hash: [u8; 20]

The Hash160 of the script.



MultiSig

A transparent threshold multisig script.

Fields

required: u8

The number of signatures required to spend.

pubkeys: Vec<BoundedVec<u8, { PubKey::COMPRESSED_SIZE }, { PubKey::SIZE }>>

The pubkeys that can be used to sign spends.



NullData

An unspendable OP_RETURN script that carries data.

Fields

data: Vec<PushValue>

The carried data.



PubKey

A legacy P2PK script.

Fields

data: BoundedVec<u8, { PubKey::COMPRESSED_SIZE }, { PubKey::SIZE }>

The encoded public key.

Implementations

Source

impl ScriptKind

pub fn as_str(&self) -> &'static str

Returns a string identifier for this script kind.

pub fn req_sigs(&self) -> u8

Returns the number of signatures required to spend an output of this script kind.