pub fn standard(script_code: &Component<Opcode>) -> Option<ScriptKind>Expand description
Parses a script::PubKey or script::Redeem and detects standard scripts.
If successful, returns the script kind, and any relevant properties parsed from the script. For example, for a P2SH script, the result will contain the script hash; for P2PKH it will contain the key hash, etc.
Returns None if the script is non-standard.