pub enum ScriptKind {
PubKeyHash {
hash: [u8; 20],
},
ScriptHash {
hash: [u8; 20],
},
MultiSig {
required: u8,
pubkeys: Vec<BoundedVec<u8, { PubKey::COMPRESSED_SIZE }, { PubKey::SIZE }>>,
},
NullData {
data: Vec<PushValue>,
},
PubKey {
data: BoundedVec<u8, { PubKey::COMPRESSED_SIZE }, { PubKey::SIZE }>,
},
}Expand description
Known kinds of standard scripts.
Variants
PubKeyHash
A P2PKH script.
ScriptHash
A P2SH script, used in transaction outputs to efficiently commit to other scripts.
MultiSig
A transparent threshold multisig script.
Fields

pubkeys: Vec<BoundedVec<u8, { PubKey::COMPRESSED_SIZE }, { PubKey::SIZE }>>The pubkeys that can be used to sign spends.
NullData
An unspendable OP_RETURN script that carries data.
PubKey
A legacy P2PK script.
Fields

data: BoundedVec<u8, { PubKey::COMPRESSED_SIZE }, { PubKey::SIZE }>The encoded public key.
Implementations